@@ -282,7 +282,7 @@ void MyMainView::writeConfig()
    game.writeEntry("powerupEnergyAmount",customConfig.powerupEnergyAmount);
 }
 
-SConfig MyMainView::modifyConfig(SConfig conf)
+SConfig MyMainView::modifyConfig(const SConfig &conf)
 {
    SConfig newConfig=conf;
    newConfig.gamespeed*=Options::refreshTime()/33.0;
@@ -984,7 +984,7 @@ void MyMainView::collisions()
                      if(!hitlist.contains(sprite))
                         hitlist.append(sprite);
             }
-            if(hitlist.count()>0)
+            if(!hitlist.isEmpty())
             {
                mine->explode();
 	       foreach (QGraphicsItem *item, hitlist)
